==> spartaqube-0.1.49.tar.gz: spartaqube-0.1.49/spartaqube/manage.py <==
"""Django's command-line utility for administrative tasks."""
import os
import sys
import re
import json


def sparta_7f43c48fd5(argv):
    """
    Parses the port number from the command-line arguments passed to the runserver command.Returns the port as an integer if found, otherwise defaults to 8000."""
    default_port = 8000
    port = default_port
    if 'runserver' in argv:
        runserver_index = argv.index('runserver')
        if len(argv) > runserver_index + 1:
            address_port = argv[runserver_index + 1]
            if address_port.isdigit():
                port = int(address_port)
            else:
                match = re.search(':(\\d+)$', address_port)
                if match:
                    port = int(match.group(1))
    return port


def sparta_be196dd3f7():
    """Run administrative tasks."""
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'spartaqube_app.settings')
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and available on your PYTHONPATH environment variable? Did you forget to activate a virtual environment?"
            ) from exc
    from django.conf import settings as conf_settings
    if conf_settings.IS_DEV:
        django_port = sparta_7f43c48fd5(sys.argv)
        app_data_dict = {'default_port': django_port}
        current_path = os.path.dirname(__file__)
        api_path = os.path.join(current_path, 'api')
        with open(os.path.join(api_path, 'app_data_asgi.json'), 'w'
            ) as json_file:
            json.dump(app_data_dict, json_file)
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    sparta_be196dd3f7()

#END OF QUBE

==> spartaqube-0.1.56.tar.gz: spartaqube-0.1.56/spartaqube/manage.py <==
"""Django's command-line utility for administrative tasks."""
import os
import sys
import re
import json


def sparta_3a761e9954(argv):
    """
    Parses the port number from the command-line arguments passed to the runserver command.Returns the port as an integer if found, otherwise defaults to 8000."""
    default_port = 8000
    port = default_port
    if 'runserver' in argv:
        runserver_index = argv.index('runserver')
        if len(argv) > runserver_index + 1:
            address_port = argv[runserver_index + 1]
            if address_port.isdigit():
                port = int(address_port)
            else:
                match = re.search(':(\\d+)$', address_port)
                if match:
                    port = int(match.group(1))
    return port


def sparta_95592f1601():
    """Run administrative tasks."""
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'spartaqube_app.settings')
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and available on your PYTHONPATH environment variable? Did you forget to activate a virtual environment?"
            ) from exc
    django_port = sparta_3a761e9954(sys.argv)
    app_data_dict = {'default_port': django_port}
    current_path = os.path.dirname(__file__)
    api_path = os.path.join(current_path, 'api')
    with open(os.path.join(api_path, 'app_data_asgi.json'), 'w') as json_file:
        json.dump(app_data_dict, json_file)
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    sparta_95592f1601()

#END OF QUBE
